Learn R Programming

fitur (version 0.6.2)

GOFTests: Wrappers to compute goodness of fit test froms distfun objects

Description

Wrappers to compute goodness of fit test froms distfun objects

Usage

ks_test(distfun, x, ...)

# S3 method for distfun ad_test(distfun, x)

ad_test(distfun, x)

# S3 method for distfun cvm_test(distfun, x)

cvm_test(distfun, x)

Arguments

distfun

a distfun object

x

numeric vector

...

arguments to be passed on to test function

Value

goodness of fit object

Examples

Run this code
# NOT RUN {
x <- rgamma(100, 1, 1)
fit <- fit_univariate(x, 'gamma')
ks_test(fit, x)
ad_test(fit, x)
cvm_test(fit, x)
# }

Run the code above in your browser using DataLab